# pyexql

## Dev Setup

Connector version is 2.7.12, python version is 3.9
1. Snowflake connector requirements: `pip install -r https://raw.githubusercontent.com/snowflakedb/snowflake-connector-python/v2.7.12/tested_requirements/requirements_39.reqs`
2. Connector: `pip install snowflake-connector-python==2.7.12`
